@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -25,6 +25,7 @@ import os
 import sys
 import subprocess
 import select
+import time
 if sys.platform=='win32':
 	import win32api
 	import win32process
@@ -49,9 +50,9 @@ class executor:
 				progresbar.set_text(" ")
 			self.filefolder=filefolder
 			self.filename=filename
+			self.platform_win32=(sys.platform=='win32')
 			self.handle=None
 			self.cadena=""
-			self.platform_win32=(sys.platform=='win32')
 			self.printout=True
 			self.print_error="Undefined error"
 
@@ -85,8 +86,8 @@ class executor:
 	def launch_shell(self,program,read_chars=80,output=True,stdinout=None):
 		
 		""" Launches a program from a command line shell. Usefull for programs like SPUMUX, which
-		takes the input stream from STDIN and gives the output stream to STDOUT, or for programs like
-		COPY, CP or LN """
+		takes the input stream from STDIN and gives the output stream to STDOUT, or for programs
+		like COPY, CP or LN """
 		
 		self.read_chars=read_chars
 		self.output=output
@@ -138,7 +139,7 @@ class executor:
 		return None	
 
 
-	def launch_program(self,program,read_chars=80,output=True,win32arg=True):
+	def launch_program(self,program,read_chars=80,output=True,win32arg=True,with_stderr=True):
 
 		""" Launches a program that can be located in any of the directories stored in PATHLIST """
 
@@ -151,7 +152,9 @@ class executor:
 		else:
 			pathlist=["/usr/local/bin","/usr/bin","/usr/local/bin","/usr/share/bin","/usr/share/local/bin","/bin",os.path.join(wd[0],"bin")]
 
-		print "Launching program: "+str(program)
+		print "Launching program: ",
+		for elemento in program:
+			print str(elemento),
 		print
 
 		for elemento in pathlist:
@@ -162,10 +165,16 @@ class executor:
 				program2=program[:]
 				program2[0]=elemento+program2[0]
 				if output:
-					if sys.platform=='win32':
-						handle=MyPopen(program2,executable=program2[0],shell=False,stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, creationflags=win32process.CREATE_NO_WINDOW, threaded=win32arg, read=read_chars)
+					if with_stderr:
+						if sys.platform=='win32':
+							handle=MyPopen(program2,executable=program2[0],shell=False,stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, creationflags=win32process.CREATE_NO_WINDOW, threaded=win32arg, read=read_chars)
+						else:
+							handle=subprocess.Popen(program2,executable=program[0],shell=False,bufsize=32767,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
 					else:
-						handle=subprocess.Popen(program2,executable=program[0],shell=False,bufsize=32767,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
+						if sys.platform=='win32':
+							handle=MyPopen(program2,executable=program2[0],shell=False,stdin=subprocess.PIPE, stdout=subprocess.PIPE, creationflags=win32process.CREATE_NO_WINDOW, threaded=win32arg, read=read_chars)
+						else:
+							handle=subprocess.Popen(program2,executable=program[0],shell=False,bufsize=32767,stdout=subprocess.PIPE)
 				else:
 					if sys.platform=='win32':
 						handle=MyPopen(program2,executable=program2[0],shell=False,creationflags=win32process.CREATE_NO_WINDOW, threaded=win32arg, read=read_chars)
@@ -200,34 +209,45 @@ class executor:
 		ret_value=1
 		v1=[]
 		while self.handle.poll()==None:
-			if self.platform_win32:
-				v1 = self.handle.recv_some()
-			else:
-				v1,v2,v3=select.select([self.handle.stderr,self.handle.stdout],[],[],0)
-
-			if len(v1)==0:
+			if self.read_line_from_output():
 				ret_value=0
-				break # nothing to read, so get out of the WHILE loop
+				break
 			
-			for element in v1:
-				if sys.platform=="win32":
-					readed = element#[0,self.read_chars]
-					self.cadena+=readed
-					if (self.printout):
-						print readed,
-					break # this break statement and setting the priority lower in launch_program makes devede work a lot better on windows
-				else:
-					readed=element.readline(self.read_chars)
-					self.cadena+=readed
-					if (self.printout) or (v1==self.handle.stderr):
-						print readed,
-
 		if (self.set_progress_bar()): # progress_bar is defined in each subclass to fit the format
 			self.cadena=""
 		
+		if ret_value==1: # read what remains in the STDOUT and STDERR queues
+			while self.read_line_from_output():
+				tmp=1
+		
 		return ret_value # 0: nothing to read; 1: program ended
 
 
+	def read_line_from_output(self):
+		if self.platform_win32:
+			v1 = self.handle.recv_some()
+		else:
+			v1,v2,v3=select.select([self.handle.stderr,self.handle.stdout],[],[],0)
+
+		if len(v1)==0:
+			return True # nothing to read, so get out of the WHILE loop
+		
+		for element in v1:
+			if sys.platform=="win32":
+				readed = element#[0,self.read_chars]
+				self.cadena+=readed
+				if (self.printout):
+					print readed,
+				break # this break statement and setting the priority lower in launch_program makes devede work a lot better on windows
+			else:
+				readed=element.readline(self.read_chars)
+				self.cadena+=readed
+				if (self.printout) or (v1==self.handle.stderr):
+					print readed,
+
+		return False
+	
+
 	def set_progress_bar(self):
 		
 		# By default, just do nothing
@@ -342,7 +362,7 @@ class MyPopen(subprocess.Popen):
 		return out #[out, err]
 
 
-def set_priority(self, pid=None, priority=0):
+	def set_priority(self, pid=None, priority=0):
 
 		"""
 		Set the Priority of a Windows Process.  Priority is a value between 0-5 where
