@@ -29,7 +29,7 @@ def prepare_devede_font(home,font_path):
 		It's made this way because Red Hat package mandates removing font files
 		from RPM files, so DeVeDe must search in several directories """
 	
-	path_list=[font_path,"/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf","/usr/share/fonts/truetype/ttf-dejavu/dejavusans.ttf"]
+	path_list=[font_path,"/usr/local/lib/X11/fonts/dejavu/DejaVuSans.ttf","/usr/local/lib/X11/fonts/dejavu/dejavusans.ttf"]
 	
 	#if our font for subtitles isn't installed, we install it
 
