@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -124,6 +124,12 @@ class load_save_config:
 					element2["hmirror"]=False
 				if False==element2.has_key("gop12"):
 					element2["gop12"]=True # for backward compatibility
+				if False==element2.has_key("isvob"):
+					element2["isvob"]=False # for backward compatibility
+				if False==element2.has_key("swap_fields"):
+					element2["swap_fields"]=False # for backward compatibility
+				if False==element2.has_key("subfont_size"):
+					self.file_properties["subfont_size"]=28 # subtitle font size
 				
 				if False==element2.has_key("audio_stream"):
 					fileprop=devede_newfiles.newfile("","")
@@ -159,13 +165,15 @@ class load_save_config:
 		except:
 			w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu background. I'll open the disc structure anyway with the default menu background, so don't forget to fix it before creating the disc."))
 			w = None
-			global_vars2["menu_bg"]=self.global_vars["path"]+"background.png"
+			global_vars2["menu_bg"]=os.path.join(self.global_vars["path"],"backgrounds","default_bg.png")
 			
 		use_default_sound=False
 		
 		if False==global_vars2.has_key("menu_sound"):
 			use_default_sound=True
 		else:
+			if (global_vars2["menu_sound"][-11:]=="silence.mp3"):
+				global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 			try:
 				os.stat(global_vars2["menu_sound"])
 			except:
@@ -182,13 +190,13 @@ class load_save_config:
 		if False==global_vars2.has_key("menu_title_shadow"):
 			global_vars2["menu_title_shadow"]=[0,0,0,0]
 			
-		if use_default_sound:
-			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+		if (use_default_sound):
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 
 		test=devede_newfiles.file_get_params()
 		check,channels=test.read_file_values(global_vars2["menu_sound"],True)
 		if (check!=False) or (channels!=1):
-			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 			w = devede_dialogs.show_error(self.gladefile,_("The menu soundtrack seems damaged. Using the default silent soundtrack."))
 			w = None
 			check,channels=test.read_file_values(global_vars2["menu_sound"],True)
