@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -115,8 +115,8 @@ class main_window:
 		self.global_vars["erase_files"]=True
 		self.global_vars["struct_name"]=""
 		self.global_vars["do_menu"]=True
-		self.global_vars["menu_bg"]=os.path.join(self.global_vars["path"],"background.png")
-		self.global_vars["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+		self.global_vars["menu_bg"]=os.path.join(self.global_vars["path"],"backgrounds","default_bg.png")
+		self.global_vars["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 		test=devede_newfiles.file_get_params()
 		check,channels=test.read_file_values(self.global_vars["menu_sound"],True)
 		if (check!=False) or (channels!=1):
@@ -326,7 +326,7 @@ class main_window:
 		
 		for element in self.structure:
 			for element2 in element[1:]:
-				if element2["ismpeg"]:
+				if (element2["ismpeg"]) or (element2["isvob"]):
 					fixed_size.append(element2)
 				else:
 					variable_size.append(element2)
@@ -478,16 +478,10 @@ class main_window:
 		for title in self.structure:
 			total+=len(title)-1
 	
-		if self.disctocreate=="dvd":
-			
-			if total>61:
-				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is %(MAX)d. Please, remove some files and try again.")) % {"X":total , "MAX":61})
-				return
-
-		else:
-			if total>99:
-				devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is %(MAX)d. Please, remove some files and try again.")) % {"X":total , "MAX":99})
-				return
+		maxtitles=devede_other.get_max_titles(self.disctocreate)
+		if total>maxtitles:
+			devede_dialogs.show_error(self.gladefile,(_("Your project contains %(X)d movie files, but the maximum is %(MAX)d. Please, remove some files and try again.")) % {"X":total , "MAX":maxtitles})
+			return
 	
 		actions=0	
 		w=self.tree.get_object("only_convert")
@@ -916,7 +910,7 @@ class main_window:
 			
 			w=self.tree.get_object("eleng")
 			speed1,speed2=devede_other.get_speedup(found)
-			length=devede_other.calcula_tamano_parcial(found["vrate"],found["arate"],found["filesize"],found["olength"],len(found["sub_list"]),found["ismpeg"],found["cutting"],speed1,speed2)
+			length=devede_other.calcula_tamano_parcial(found["vrate"],found["arate"],found["filesize"],found["olength"],len(found["sub_list"]),found["ismpeg"],found["isvob"],found["cutting"],speed1,speed2)
 			#length=int(((found["vrate"]+found["arate"])*found["olength"])/8000)
 			w.set_text(str(int(length/1000)))
 			
@@ -930,7 +924,7 @@ class main_window:
 			if found["fps"]==25:
 				w.set_text("25 (PAL)")
 			elif found["fps"]==30:
-				if (found["ofps"]==24) and ((self.disctocreate=="dvd") or (self.disctocreate=="divx")):
+				if (found["ofps"]==24) and (self.disctocreate!="vcd") and (self.disctocreate!="svcd") and (self.disctocreate!="cvd"):
 					w.set_text("24 (NTSC)")
 				else:
 					w.set_text("30 (NTSC)")
