@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -61,6 +61,7 @@ import devede_help
 
 class file_get_params(devede_executor.executor):
 
+
 	def read_file_values(self,filename,check_audio):
 
 		""" Reads the values of the video (width, heigth, fps...) and stores them
@@ -96,8 +97,8 @@ class file_get_params(devede_executor.executor):
 			command="mplayer.exe"
 		else:
 			command="mplayer"
-		launcher=[command, "-identify", "-ao", "null", "-vo", "null", "-frames", str(nframes), filename]
-		handler=self.launch_program(launcher, win32arg=False)
+		launcher=[command, "-loop","1","-identify", "-ao", "null", "-vo", "null", "-frames", str(nframes), filename]
+		handler=self.launch_program(launcher, win32arg=False,with_stderr=False)
 
 		minimum_audio=10000
 		audio_list=[]
@@ -154,7 +155,7 @@ class file_get_params(devede_executor.executor):
 		
 		if aspect_ratio==0.0:
 			aspect_ratio=(float(width))/(float(height))
-			if aspect_ratio<(4.0/3.0):
+			if aspect_ratio<=1.5:
 				aspect_ratio=(4.0/3.0)
 		
 		self.file_values={}
@@ -343,6 +344,9 @@ class newfile(file_get_params):
 		self.file_properties["params_lame"]="" # no mencoder extra LAME parameters
 		self.file_properties["ismpeg"]=False # is already an MPEG-2 compliant file
 		self.file_properties["copy_audio"]=False # recompress the audio
+		self.file_properties["isvob"]=False # recompress both audio and video
+		self.file_properties["swap_fields"]=False # swap fields in interlaced videos
+		self.file_properties["subfont_size"]=28 # subtitle font size
 		self.file_properties["sound51"]=False # don't use 5.1 sound
 		self.file_properties["gop12"]=True # GOP of 12 by default to increase compatibility
 		self.file_properties["filesize"]=os.stat(filename)[stat.ST_SIZE] # file size
@@ -495,7 +499,7 @@ class file_properties(newfile):
 		w.hide()
 		
 		w=self.tree.get_object("file_split_frame")
-		if (self.disctocreate=="vcd"):
+		if (self.disctocreate=="vcd") or (self.disctocreate=="svcd") or (self.disctocreate=="cvd"):
 			w.show()
 		else:
 			w.hide()
@@ -531,6 +535,7 @@ class file_properties(newfile):
 		self.file_filter_videos.set_name(_("Video files"))
 		if sys.platform!="win32":
 			self.file_filter_videos.add_mime_type("video/*")
+			self.file_filter_videos.add_pattern("*.rmvb")
 		else:
 			self.file_filter_videos.add_custom(gtk.FILE_FILTER_FILENAME|gtk.FILE_FILTER_DISPLAY_NAME, self.custom_video_filter)
 		self.file_filter_all=gtk.FileFilter()
@@ -664,9 +669,14 @@ class file_properties(newfile):
 		w=self.tree.get_object("ismpeg")
 		self.file_properties["ismpeg"]=w.get_active()
 
+		self.file_properties["swap_fields"]=self.tree.get_object("swap_fields").get_active()
+
 		w=self.tree.get_object("copy_audio")
 		self.file_properties["copy_audio"]=w.get_active()
 
+		w=self.tree.get_object("isvob")
+		self.file_properties["isvob"]=w.get_active()
+
 		w=self.tree.get_object("sound51")
 		self.file_properties["sound51"]=w.get_active()
 
@@ -679,6 +689,9 @@ class file_properties(newfile):
 			self.file_properties["lchapters"]=w.get_value()
 		else:
 			self.file_properties["lchapters"]=0
+
+		w=self.tree.get_object("subfont_size")
+		self.file_properties["subfont_size"]=int(w.get_value())
 	
 		w=self.tree.get_object("audiodelay")
 		self.file_properties["adelay"]=float(w.get_value())
@@ -880,6 +893,7 @@ class file_properties(newfile):
 		
 		self.adjust_resolution()
 		self.set_global_values()
+		self.set_film_buttons()
 
 
 	def on_length_toggled(self,widget):
@@ -926,6 +940,12 @@ class file_properties(newfile):
 		self.set_global_values()
 
 
+	def on_isvob_toggled(self,widget):
+		
+		self.set_film_buttons()
+		self.set_global_values()
+
+
 	def on_sound51_toggled(self,widget):
 
 		self.set_film_buttons()
@@ -1031,20 +1051,26 @@ class file_properties(newfile):
 		dsize,minvid,maxvid=devede_other.get_dvd_size(None,self.disctocreate)
 
 		if self.disctocreate=="vcd":
-			w=self.tree.get_object("video_rate")
+			w=self.tree.get_object("video_rate_adj")
 			w.set_value(1152)
-			w=self.tree.get_object("audio_rate")
+			w=self.tree.get_object("audio_rate_adj")
 			w.set_value(224)
 		elif (self.disctocreate=="svcd") or (self.disctocreate=="cvd"):
-			w=self.tree.get_object("audio_rate")
-			w.set_range(64,384)
+			w=self.tree.get_object("audio_rate_adj")
+			w.set_lower(64)
+			w.set_upper(384)
+			#w.set_range(64,384)
 		else:
-			w=self.tree.get_object("audio_rate")
-			w.set_range(128,448)
+			w=self.tree.get_object("audio_rate_adj")
+			w.set_lower(128)
+			w.set_upper(448)
+			#w.set_range(128,448)
 			
 		if self.disctocreate!="vcd":
-			w=self.tree.get_object("video_rate")
-			w.set_range(minvid,maxvid)
+			w=self.tree.get_object("video_rate_adj")
+			w.set_lower(minvid)
+			w.set_upper(maxvid)
+			#w.set_range(minvid,maxvid)
 
 		if self.file_properties==None:
 			return
@@ -1106,12 +1132,21 @@ class file_properties(newfile):
 
 		w=self.tree.get_object("copy_audio")
 		w.set_active(self.file_properties["copy_audio"])
+
+		w=self.tree.get_object("isvob")
+		w.set_active(self.file_properties["isvob"])
 	
 		w=self.tree.get_object("sound51")
 		w.set_active(self.file_properties["sound51"])
 		
 		w=self.tree.get_object("gop12")
 		w.set_active(self.file_properties["gop12"])
+		
+		w=self.tree.get_object("subfont_size")
+		w.set_value(self.file_properties["subfont_size"])
+		
+		w=self.tree.get_object("swap_fields")
+		w.set_active(self.file_properties["swap_fields"])
 	
 		w=self.tree.get_object("custom_params")
 		w.set_text(self.file_properties["params"])
@@ -1241,26 +1276,49 @@ class file_properties(newfile):
 			w.set_sensitive(True)
 			w1.set_sensitive(True)
 
-		w=self.tree.get_object("ismpeg")
-		if w.get_active():
+		w0=self.tree.get_object("ismpeg")
+		if w0.get_active():
 			grupo2=False
 		else:
 			grupo2=True
 
-		w=self.tree.get_object("copy_audio")
-		if w.get_active():
+		w1=self.tree.get_object("copy_audio")
+		if w1.get_active():
 			copy_audio=False
 		else:
 			copy_audio=grupo2
 
+		w2=self.tree.get_object("isvob")
+		if w2.get_active():
+			isvob=False
+		else:
+			isvob=grupo2
+
 		if (self.disctocreate!="dvd") and (self.disctocreate!="divx"):
-			w.set_active(False)
-			w.set_sensitive(False)
+			w1.set_active(False)
+			w1.set_sensitive(False)
 			sound51=False
 		else:
-			w.set_sensitive(grupo2)
+			w1.set_sensitive(grupo2)
 			sound51=grupo2
 
+		if w0.get_active():
+			w1.set_sensitive(False)
+			w2.set_sensitive(False)
+		else:
+			w1.set_sensitive(True)
+			w2.set_sensitive(True)
+
+		if w1.get_active():
+			w2.set_sensitive(False)
+		else:
+			w2.set_sensitive(True)
+
+		if w2.get_active():
+			w1.set_sensitive(False)
+		else:
+			w1.set_sensitive(True)
+
 		if self.disctocreate =="vcd":
 			grupo1=False
 		else:
@@ -1269,11 +1327,17 @@ class file_properties(newfile):
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
 			w=self.tree.get_object("sound51")
 			if w.get_active():
-				w=self.tree.get_object("audio_rate")
-				w.set_range(384,448)		
+				w=self.tree.get_object("audio_rate_adj")
+				w.set_lower(348)
+				w.set_upper(448)
+				if w.get_value()<348:
+					w.set_value(348)
+				#w.set_range(384,448)		
 			else:
-				w=self.tree.get_object("audio_rate")
-				w.set_range(128,448)
+				w=self.tree.get_object("audio_rate_adj")
+				w.set_lower(128)
+				w.set_upper(448)
+				#w.set_range(128,448)
 
 		grupo3=grupo2
 		try:
@@ -1283,28 +1347,34 @@ class file_properties(newfile):
 			grupo3=False
 
 		w=self.tree.get_object("video_rate")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("audio_rate")
-		w.set_sensitive(grupo1 and copy_audio)
+		w.set_sensitive(grupo1 and copy_audio and isvob)
+		w=self.tree.get_object("swap_fields")
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("gop12")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("sound51")
-		if not(grupo1 and copy_audio):
+		if grupo1==False:
 			w.set_active(False)
-		w.set_sensitive(sound51 and copy_audio)
+		w.set_sensitive(sound51)
 		w=self.tree.get_object("resauto")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
+		if w.get_active():
+			set_aspect=False
+		else:
+			set_aspect=True
 		w=self.tree.get_object("res352x240")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("res352x480")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("res480x480")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("res704x480")
-		w.set_sensitive(grupo1)
+		w.set_sensitive(grupo1 and isvob)
 		w=self.tree.get_object("res720x480")
-		w.set_sensitive(grupo1)
-	
+		w.set_sensitive(grupo1 and isvob)
+		
 		w=self.tree.get_object("full_length")
 		w.set_sensitive(grupo3)
 		w=self.tree.get_object("first_half")
@@ -1312,23 +1382,23 @@ class file_properties(newfile):
 		w=self.tree.get_object("second_half")
 		w.set_sensitive(grupo3)
 		w=self.tree.get_object("video_pal")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("video_ntsc")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("audiodelay")
-		w.set_sensitive(copy_audio)
+		w.set_sensitive(copy_audio and isvob)
 		w=self.tree.get_object("blackbars")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("scalepict")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("custom_params")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("custom_params_vf")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("custom_params_lavcopts")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("custom_params_lameopts")
-		w.set_sensitive(copy_audio)
+		w.set_sensitive(copy_audio and isvob)
 		w2=self.tree.get_object("lameopts_label")
 		if self.disctocreate=="divx":
 			w.show()
@@ -1338,44 +1408,46 @@ class file_properties(newfile):
 			w2.hide()
 
 		w=self.tree.get_object("trell")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		
 		w=self.tree.get_object("rotation0")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("rotation90")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("rotation180")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("rotation270")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("hmirror")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("vmirror")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		
 		w=self.tree.get_object("mbd")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("mbd1")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("mbd2")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace_lb")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace_md")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace_fd")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("deinterlace_l5")
-		w.set_sensitive(grupo2)
+		w.set_sensitive(grupo2 and isvob)
+		w=self.tree.get_object("deinterlace_yadif")
+		w.set_sensitive(grupo2 and isvob)
 		w=self.tree.get_object("audiotrack")
 		w.set_sensitive(grupo2)
 		w1=self.tree.get_object("aspect_ratio_4_3")
 		w2=self.tree.get_object("aspect_ratio_16_9")
 		if (self.disctocreate == "dvd") or (self.disctocreate == "divx"):
-			w1.set_sensitive(grupo2)
-			w2.set_sensitive(grupo2)
+			w1.set_sensitive(grupo2 and isvob and set_aspect)
+			w2.set_sensitive(grupo2 and isvob and set_aspect)
 		else:
 			w1.set_sensitive(False)
 			w2.set_sensitive(False)
@@ -1456,6 +1528,7 @@ class file_properties(newfile):
 			w.set_text("")
 		else:
 			w2=self.tree.get_object("ismpeg")
+			w4=self.tree.get_object("isvob")
 			props={}
 			props["ofps"]=self.file_properties["ofps"]
 			props["ofps2"]=self.file_properties["ofps2"]
@@ -1470,7 +1543,7 @@ class file_properties(newfile):
 			props["ismpeg"]=w3.get_active()
 			print "Props: "+str(props)
 			speed1,speed2=devede_other.get_speedup(props)
-			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),divide2,speed1,speed2)
+			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),w4.get_active,divide2,speed1,speed2)
 			#if w2.get_active():
 			#	l=int(self.file_properties["filesize"]/1000000)
 			#else:
