@@ -2,8 +2,8 @@
 # -*- coding: UTF-8 -*-
 
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -32,6 +32,16 @@ import devede_other
 
 class subtitles_adder(devede_executor.executor):
 	
+	def expand_xml(self,text):
+		
+		text=text.replace('&','&amp;')
+		text=text.replace('<','&lt;')
+		text=text.replace('>','&gt;')
+		text=text.replace('"','&quot;')
+		text=text.replace("'",'&apos;')
+		return text
+
+	
 	def __init__(self,videofile,filename,filefolder,progresbar,proglabel,disctype,title,chapter,stream):
 
 		""" This class adds the subtitles to an already converted file
@@ -60,7 +70,7 @@ class subtitles_adder(devede_executor.executor):
 		try:
 			fichero=open(filefolder+filename+"_sub.xml","w")
 			fichero.write('<subpictures>\n\t<stream>')
-			fichero.write('\n\t\t<textsub filename="'+subtitle_list["subtitles"]+'"')
+			fichero.write('\n\t\t<textsub filename="'+self.expand_xml(subtitle_list["subtitles"])+'"')
 			if sys.platform == "win32":
 				if os.path.isfile(os.environ["WINDIR"] + os.sep + "Fonts" + os.sep + "devedesans.ttf"):
 					fichero.write('\n\t\tfont="devedesans.ttf"')
@@ -75,11 +85,11 @@ class subtitles_adder(devede_executor.executor):
 			if (videofile["fps"]==25):
 				ancho=716
 				alto=572
-				tamanofont=28
+				tamanofont=videofile["subfont_size"]
 			else:
 				ancho=716
 				alto=476
-				tamanofont=28
+				tamanofont=videofile["subfont_size"]
 
 			margin_hor=int((58*ancho)/720)
 			margin_vert=int((28*alto)/576)
