@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -76,16 +76,23 @@ class video_converter(devede_executor.executor):
 		
 			print "\ncurrentfile is: ", currentfile , "\n" 
 
+			try:
+				os.remove(currentfile)
+			except:
+				pass
+
 			if sys.platform=='win32':
 				# links do not work on windows, so just copy the file
-				self.launch_shell('copy "'+videofile["path"] +'" "'+currentfile+'"',output=False)
+				self.launch_shell('copy "'+videofile["path"].replace('"','""')+'" "'+currentfile+'"',output=False)
 			else:
 				if len(videofile["sub_list"])==0:
-					self.launch_shell('ln -s "'+videofile["path"]+'" "'+currentfile+'"',output=False)
+					self.launch_shell('ln -s "'+videofile["path"].replace('"','\\"')+'" "'+currentfile+'"',output=False)
 				else:
-					self.launch_shell('cp "'+videofile["path"]+'" "'+currentfile+'"',output=False)
+					self.launch_shell('cp "'+videofile["path"].replace('"','\\"')+'" "'+currentfile+'"',output=False)
 			return
 
+		isvob=videofile["isvob"]
+
 		self.pulse=False
 		if seconds==0:
 			texto=_("Converting files from title")
@@ -96,7 +103,6 @@ class video_converter(devede_executor.executor):
 
 		addbars=False
 		framerate=int(videofile["ofps"])
-
 		videorate=int(videofile["vrate"])
 		audiorate=int(videofile["arate"])
 		audio_final_rate=int(videofile["arateunc"])
@@ -112,6 +118,11 @@ class video_converter(devede_executor.executor):
 		sound51=videofile["sound51"]
 		gop12=videofile["gop12"]
 		audiostream=videofile["audio_stream"]
+		swap_fields=videofile["swap_fields"]
+		if (videofile["resolution"]==0) and (disctype=="divx"):
+			default_res=True
+		else:
+			default_res=False
 		
 		speed1,speed2=devede_other.get_speedup(videofile)
 		if speed1==speed2:
@@ -179,30 +190,33 @@ class video_converter(devede_executor.executor):
 		else:
 			audio_desired_final_rate=44100
 
-		if ((audio_final_rate!=audio_desired_final_rate) and (copy_audio==False)) or (speedup!=None):
-			command_var.append("-srate")
-			command_var.append(str(audio_desired_final_rate))
-			command_var.append("-af")
-			command_var.append("lavcresample="+str(audio_desired_final_rate))
+		if isvob==False:
+			if ((audio_final_rate!=audio_desired_final_rate) and (copy_audio==False)) or (speedup!=None):
+				command_var.append("-srate")
+				command_var.append(str(audio_desired_final_rate))
+				command_var.append("-af")
+				command_var.append("lavcresample="+str(audio_desired_final_rate))
 
-		# Add the speedup code
+			# Add the speedup code
 
-		if speedup!=None:
-			command_var.append("-speed")
-			command_var.append(speedup)
+			if speedup!=None:
+				command_var.append("-speed")
+				command_var.append(speedup)
 
 		command_var.append("-oac")
-		if copy_audio:
+		if copy_audio or isvob:
 			command_var.append("copy")
 		else:
 			if (disctype=="divx"):
 				command_var.append("mp3lame")
 			else:
 				command_var.append("lavc")
-		
+
 		if (audiostream!=10000):
 			command_var.append("-aid")
 			command_var.append(str(audiostream))
+
+
 		
 		telecine=False
 		if final_framerate==30:
@@ -221,13 +235,17 @@ class video_converter(devede_executor.executor):
 			keyintv=12
 		
 		command_var.append("-ovc")
-		command_var.append("lavc")
+		if isvob:
+			command_var.append("copy")
+		else:
+			command_var.append("lavc")
+		
 		if (disctype!="divx"):
 			command_var.append("-of")
 			command_var.append("mpeg")
 			command_var.append("-mpegopts")
 			if disctype=="dvd":
-				if telecine:
+				if telecine and isvob==False:
 					command_var.append("format=dvd:tsaf:telecine")
 				else:
 					command_var.append("format=dvd:tsaf")
@@ -250,16 +268,17 @@ class video_converter(devede_executor.executor):
 				command_var.append("-ss")
 				command_var.append(str((videofile["olength"]/2)-5)) # start 5 seconds before
 
-		if (audiodelay!=0.0) and (copy_audio==False):
+		if (audiodelay!=0.0) and (copy_audio==False) and (isvob==False):
 			command_var.append("-delay")
 			command_var.append(str(audiodelay))
-			
+
 		if sound51:
 			command_var.append("-channels")
 			command_var.append("6")
-	
-		command_var.append("-ofps")
-		command_var.append(str_final_framerate)
+
+		if (isvob==False) and (default_res==False):
+			command_var.append("-ofps")
+			command_var.append(str_final_framerate)
 
 		if disctype=="divx":
 			command_var.append("-ffourcc")
@@ -268,6 +287,10 @@ class video_converter(devede_executor.executor):
 		lineatemp=""
 		acoma=False;
 		
+		if swap_fields:
+			lineatemp+="phase=a"
+			acoma=True
+		
 		extra_params=videofile["params_vf"] # take the VF extra params
 		while (extra_params!=""):
 			extra_params,new_param=devede_other.get_new_param(extra_params)
@@ -317,7 +340,7 @@ class video_converter(devede_executor.executor):
 		
 		print "Addbars "+str(addbars)+" resx_o "+str(resx_original)+" resy_o "+str(resy_original)
 		print "resx_i "+str(resx_inter)+" resy_i "+str(resy_inter)
-		if addbars and ((resx_inter!=resx_original) or (resy_inter!=resy_original)):
+		if addbars and ((resx_inter!=resx_original) or (resy_inter!=resy_original)) and (default_res==False):
 			if acoma:
 				lineatemp+=","
 			lineatemp+="expand="+str(resx_inter)+":"+str(resy_inter)+":"+str(addx)+":"+str(addy)
@@ -335,7 +358,7 @@ class video_converter(devede_executor.executor):
 			lineatemp+="rotate=2"
 			acoma=True
 
-		if (resx_inter!=resx_final) or (resy_inter!=resy_final):
+		if ((resx_inter!=resx_final) or (resy_inter!=resy_final)) and (default_res==False):
 			if acoma:
 				lineatemp+=","
 			lineatemp+="scale="+str(resx_final)+":"+str(resy_final)
@@ -347,82 +370,85 @@ class video_converter(devede_executor.executor):
 			lineatemp+="harddup"
 			acoma=True
 
-		if (lineatemp!=""):
+		if (lineatemp!="") and (isvob==False):
 			command_var.append("-vf")		
 			command_var.append(lineatemp)
 
-		command_var.append("-lavcopts")
+		if isvob==False:
+			command_var.append("-lavcopts")
+			
+			lavcopts=""
+			
+			# Currently Mencoder supports up to 8 threads
+			if threads>8:
+				nthreads=8
+			else:
+				nthreads=threads
+			
+			if nthreads>1:
+				lavcopts="threads="+str(nthreads)+":"
+			lavcopts+="vcodec="
+			if disctype=="vcd":
+				lavcopts+="mpeg1video"
+			elif disctype=="divx":
+				lavcopts+="mpeg4"
+			else:
+				lavcopts+="mpeg2video"
 		
-		lavcopts=""
+			if videofile["trellis"]:
+				lavcopts+=":trell"
 		
-		# Currently Mencoder supports up to 8 threads
-		if threads>8:
-			nthreads=8
-		else:
-			nthreads=threads
-		
-		if nthreads>1:
-			lavcopts="threads="+str(nthreads)+":"
-		lavcopts+="vcodec="
-		if disctype=="vcd":
-			lavcopts+="mpeg1video"
-		elif disctype=="divx":
-			lavcopts+="mpeg4"
-		else:
-			lavcopts+="mpeg2video"
+			if videofile["mbd"]==0:
+				lavcopts+=":mbd=0"	
+			elif videofile["mbd"]==1:
+				lavcopts+=":mbd=1"
+			elif videofile["mbd"]==2:
+				lavcopts+=":mbd=2"
 	
-		if videofile["trellis"]:
-			lavcopts+=":trell"
-	
-		if videofile["mbd"]==0:
-			lavcopts+=":mbd=0"	
-		elif videofile["mbd"]==1:
-			lavcopts+=":mbd=1"
-		elif videofile["mbd"]==2:
-			lavcopts+=":mbd=2"
+			lavcopts+=":sc_threshold=1000000000:cgop"
 
-		lavcopts+=":sc_threshold=1000000000:cgop"
-		if disctype!="divx":
-			lavcopts+=":vstrict=0:vrc_maxrate="+str(max_videorate)
-			lavcopts+=":vrc_buf_size="
-			if (disctype=="vcd"):
-				lavcopts+="327"
-			elif (disctype=="svcd") or (disctype=="cvd"):
-				lavcopts+="917"
-			elif (disctype=="dvd"):
-				lavcopts+="1835"
-		if disctype=="vcd":
-			lavcopts+=":vrc_minrate="+str(min_videorate)
-
-		lavcopts+=":vbitrate="+str(videorate)
+			if disctype!="divx":
+				lavcopts+=":vstrict=0:vrc_maxrate="+str(max_videorate)
+				lavcopts+=":vrc_buf_size="
+				if (disctype=="vcd"):
+					lavcopts+="327"
+				elif (disctype=="svcd") or (disctype=="cvd"):
+					lavcopts+="917"
+				elif (disctype=="dvd"):
+					lavcopts+="1835"
+			if disctype=="vcd":
+				lavcopts+=":vrc_minrate="+str(min_videorate)
 	
-		if disctype!="divx":
-			lavcopts+=":keyint="+str(keyintv)
-			if(copy_audio==False):
-				lavcopts+=":acodec="
-				if disctype=="dvd":
-					lavcopts+="ac3"
+			lavcopts+=":vbitrate="+str(videorate)
+		
+			if disctype!="divx":
+				lavcopts+=":keyint="+str(keyintv)
+				if(copy_audio==False):
+					lavcopts+=":acodec="
+					if disctype=="dvd":
+						lavcopts+="ac3"
+					else:
+						lavcopts+="mp2"
+					lavcopts+=":abitrate="+str(audiorate)
+
+			if (default_res==False):
+				if aspect_ratio_final>1.4:
+					lavcopts+=":aspect=16/9"
 				else:
-					lavcopts+="mp2"
-				lavcopts+=":abitrate="+str(audiorate)
+					lavcopts+=":aspect=4/3"
 	
-		if aspect_ratio_final>1.4:
-			lavcopts+=":aspect=16/9"
-		else:
-			lavcopts+=":aspect=4/3"
-
-		extra_params=videofile["params_lavc"] # take the LAVC extra params
-		while (extra_params!=""):
-			extra_params,new_param=devede_other.get_new_param(extra_params)
-			if (new_param!="") and (new_param!=':'):
-				while (len(new_param)>1) and (new_param[0]==':'):
-					new_param=new_param[1:]
-				while (len(new_param)>1) and (new_param[-1]==':'):
-					new_param=new_param[:-1]
-				lavcopts+=":"+new_param
-		command_var.append(lavcopts)
+			extra_params=videofile["params_lavc"] # take the LAVC extra params
+			while (extra_params!=""):
+				extra_params,new_param=devede_other.get_new_param(extra_params)
+				if (new_param!="") and (new_param!=':'):
+					while (len(new_param)>1) and (new_param[0]==':'):
+						new_param=new_param[1:]
+					while (len(new_param)>1) and (new_param[-1]==':'):
+						new_param=new_param[:-1]
+					lavcopts+=":"+new_param
+			command_var.append(lavcopts)
 	
-		if (disctype=="divx") and (copy_audio==False):
+		if (disctype=="divx") and (copy_audio==False) and (isvob==False):
 			lameopts="abr:br="+str(audiorate)
 			command_var.append("-lameopts")
 			extra_params=videofile["params_lame"] # take the LAME extra params
