@@ -1,8 +1,8 @@
 #!/usr/local/bin/python2.5
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+import gtk
 import cairo
 import time
 import sys
@@ -282,6 +282,8 @@ class xml_files(devede_executor.executor):
 
 			fichero.write("\n")
 			
+			# Now we create the titleset for each video
+			
 			total_t=len(self.structure)
 			titleset=1
 			titles=0
@@ -361,7 +363,7 @@ class xml_files(devede_executor.executor):
 					
 					for element3 in element2["sub_list"]:
 						fichero.write('\t\t\t<subpicture lang="'+self.expand_xml(str(element3["sub_language"][:2].lower()))+'" />\n')
-					fichero.write("\t\t\t<pgc>\n")
+					fichero.write('\t\t\t<pgc>\n')
 					currentfile=self.create_filename(self.filefolder+self.filename,titles+1,files+1,False)
 					fichero.write('\t\t\t\t<vob file="'+self.expand_xml(currentfile)+'" ')
 					fichero.write('chapters="0')
@@ -422,6 +424,8 @@ class xml_files(devede_executor.executor):
 	
 	def create_menu1(self,counter,nelement,threads):
 	
+		""" Creates all the menu elements """
+	
 		self.threads=threads
 		self.counter=counter
 		self.nelement=nelement
@@ -681,7 +685,19 @@ class xml_files(devede_executor.executor):
 
 		if paint_bg==0:
 			try:
-				sf_base=cairo.ImageSurface.create_from_png(self.menu_bg)
+				print "Uso "+str(self.menu_bg)
+				extra_pixbuf = gtk.gdk.pixbuf_new_from_file(self.menu_bg)
+				extra_x = extra_pixbuf.get_width()
+				extra_y = extra_pixbuf.get_height()
+
+				sf_base = cairo.ImageSurface(0,extra_x,extra_y)
+
+				extra_ct = cairo.Context(sf_base)
+				extra_ct2 = gtk.gdk.CairoContext(extra_ct)
+
+				extra_ct2.set_source_pixbuf(extra_pixbuf,0,0)
+				extra_ct2.paint()
+				extra_ct2.stroke()
 			except:
 				return None
 
